@@ -187,13 +187,13 @@ class LuaScripts(object):
                         redis.call('HSET', p_key, v_key, v)
                     end
                 elseif field_type == 'orbool' then
-                    if (current_value == false or current_value == '1') or v == true then
+                    if (current_value == '1' or v == 1) then
                         redis.call('HSET', p_key, v_key, '1')
                     else
                         redis.call('HSET', p_key, v_key, '0')
                     end
                 elseif field_type == 'andbool' then
-                    if (current_value == false or current_value == '1') and v == true then
+                    if (current_value == false or current_value == '1') and v == 1 then
                         redis.call('HSET', p_key, v_key, '1')
                     else
                         redis.call('HSET', p_key, v_key, '0')
